SystemOrganization addCategory: #'Xtreams-CoreTests'!

TestCase subclass: #XTBufferTest
	instanceVariableNames: 'output buffer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-CoreTests'!

!XTBufferTest methodsFor: 'initialize-release' stamp: 'nice 10/9/2010 20:37'!
setUp
	
	buffer := XTBuffer on: String new! !

!XTBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:37'!
testClear

	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer clear.
	buffer write: 4 from: 'ABCD' at: 1.
	buffer read: 4 into: output at: 1.
	self assert: output = 'ABCD'.
	self assert: buffer readPosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 8! !

!XTBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:37'!
testInsertInTheMiddle

	| chunk |
	chunk := 'hello'.
	buffer write: chunk; write: chunk.
	buffer writePosition: chunk size.
	buffer insert: chunk.
	self assert: buffer writePosition = (chunk size * 2).
	self assert: buffer activeSize = (chunk size * 3)! !

!XTBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:37'!
testRead

	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 1 into: output at: 1.
	self assert: output = '1www'.
	self assert: buffer readPosition = 1.
	self assert: buffer readSize = 3.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 5.
	buffer read: 3 into: output at: 2.
	self assert: output = '1234'.
	self assert: buffer readPosition = 4.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 8! !

!XTBufferTest methodsFor: 'tests' stamp: 'MartinKobetic 1/11/2011 17:53'!
testReadOverflow

	output := 'wwwwww' copy.
	buffer write: 4 from: '1234' at: 1.
	self should: [buffer read: 6 into: output at: 1] raise: Incomplete.
	self assert: output = '1234ww'.
	self assert: buffer readPosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 8! !

!XTBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:37'!
testTrim

	output := 'wwww' copy.
	buffer write: 8 from: '12345678' at: 1.
	buffer read: 2 into: output at: 1.
	buffer writeSkip: -2.
	buffer trim.
	self assert: buffer readPosition = 0.
	self assert: buffer readSize = 4.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 0.
	buffer read: 4 into: output at: 1.
	self assert: output = '3456'.
	self assert: buffer readPosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 4! !

!XTBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:38'!
testWrite

	buffer := XTBuffer on: 'xxxx' copy.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 0.
	self assert: buffer inactiveSize = 4.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 0.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 4.
	buffer write: 1 from: '1234' at: 1.
	self assert: buffer cache = '1xxx'.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 1.
	self assert: buffer inactiveSize = 3.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 1.
	self assert: buffer readSize = 1.
	self assert: buffer writeSize = 3.
	buffer write: 3 from: '1234' at: 2.
	self assert: buffer cache = '1234'.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 4.
	self assert: buffer inactiveSize = 0.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 0! !

!XTBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:38'!
testWriteGrow

	self assert: buffer cacheSize = 0.
	self assert: buffer activeSize = 0.
	self assert: buffer inactiveSize = 0.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 0.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 0.
	buffer write: 4 from: '1234' at: 1.
	self assert: (buffer cache first: 4) = '1234'.
	self assert: buffer cacheSize = 8.
	self assert: buffer activeSize = 4.
	self assert: buffer inactiveSize = 4.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 4! !

!XTBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:38'!
testWriteObject
	
	buffer := XTBuffer on: 'xxxx' copy.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 0.
	self assert: buffer inactiveSize = 4.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 0.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 4.
	buffer put: $1.
	self assert: buffer cache = '1xxx'.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 1.
	self assert: buffer inactiveSize = 3.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 1.
	self assert: buffer readSize = 1.
	self assert: buffer writeSize = 3.
	buffer put: $2; put: $3; put: $4.
	self assert: buffer cache = '1234'.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 4.
	self assert: buffer inactiveSize = 0.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 0.
	buffer put: $5.
	self assert: (buffer cache first: 5) = '12345'.
	self assert: buffer cacheSize >= 5.
	self assert: buffer activeSize = 5.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 5.
	self assert: buffer readSize = 5.! !

TestCase subclass: #XTBufferedWriteStreamTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-CoreTests'!

!XTBufferedWriteStreamTest methodsFor: 'testing' stamp: 'cwp 8/10/2011 23:34'!
testBuffered
	| writing count |
	count := 0.
	writing := [:o | count := count + 1] writing buffering: 10.
	writing write: #[ 1 2 3 4 5 ].
	self assert: count = 0.
	writing write: #[ 6 7 8 9 ].
	self assert: count = 0.
	writing put: 10.
	self assert: count = 0.
	writing write: #[ 11 12 ].
	self assert: count = 10.
	writing flush.
	self assert: count = 12.
	writing write: #[ 13 14 ].
	self assert: count = 12.
	writing close.
	self assert: count = 14.! !

TestCase subclass: #XTElasticBufferTest
	instanceVariableNames: 'output buffer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-CoreTests'!

!XTElasticBufferTest methodsFor: 'initialize-release' stamp: 'nice 10/9/2010 20:38'!
setUp
	
	buffer := XTElasticBuffer on: String new! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:39'!
testClear

	buffer write: 4 from: '1234' at: 1.
	buffer clear.
	self assert: buffer cacheSize = 0.
	self assert: buffer readPosition = 0.
	self assert: buffer readSize = 0.
	self assert: buffer writePosition = 0.
	self assert: buffer writeSize = 0! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:39'!
testRead

	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 1 into: output at: 1.
	self assert: output = '1www'.
	self assert: buffer readPosition = 1.
	self assert: buffer readSize = 3.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 5.
	buffer read: 3 into: output at: 2.
	self assert: output = '1234'.
	self assert: buffer readPosition = 4.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 8! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'MartinKobetic 1/11/2011 17:53'!
testReadOverflow

	output := 'wwwwww' copy.
	buffer write: 4 from: '1234' at: 1.
	self should: [buffer read: 6 into: output at: 1] raise: Incomplete.
	self assert: output = '1234ww'.
	self assert: buffer readPosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 8! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:39'!
testReadWrap

	output := 'wwwwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 3 into: output at: 1.
	buffer write: 6 from: 'ABCDEF' at: 1.
	output := 'wwwwww' copy.
	buffer read: 6 into: output at: 1.
	self assert: output = '4ABCDE'.
	self assert: buffer readPosition = 7.
	self assert: buffer readSize = 1.
	self assert: buffer writePosition = 8.
	self assert: buffer writeSize = 7! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:39'!
testTrim

	output := 'wwww' copy.
	buffer write: 3 from: '1234' at: 1.
	buffer read: 1 into: output at: 1.
	buffer writeSkip: -1.
	buffer trim.
	self assert: buffer cacheSize = 2.
	self assert: buffer cache = '23'.
	self assert: buffer readPosition = 0.
	self assert: buffer readSize = 2.
	self assert: buffer writePosition = 2.
	self assert: buffer writeSize = 0! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:39'!
testTrimInsideOut

	buffer := XTElasticBuffer on: 'xxxx' copy.
	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 3 into: output at: 1.
	buffer write: 2 from: 'AB' at: 1.
	buffer writeSkip: -1.
	buffer trim.
	self assert: buffer cacheSize = 2.
	self assert: buffer cache = '4B'.
	self assert: buffer readPosition = 0.
	self assert: buffer readSize = 2.
	self assert: buffer writePosition = 2.
	self assert: buffer writeSize = 0! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:39'!
testWrite

	buffer := XTElasticBuffer on: 'xxxx' copy.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 0.
	self assert: buffer inactiveSize = 4.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 0.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 4.
	buffer write: 1 from: '1234' at: 1.
	self assert: buffer cache = '1xxx'.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 1.
	self assert: buffer inactiveSize = 3.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 1.
	self assert: buffer readSize = 1.
	self assert: buffer writeSize = 3.
	buffer write: 3 from: '1234' at: 2.
	self assert: buffer cache = '1234'.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 4.
	self assert: buffer inactiveSize = 0.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 0! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:39'!
testWriteGrow

	self assert: buffer cacheSize = 0.
	self assert: buffer activeSize = 0.
	self assert: buffer inactiveSize = 0.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 0.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 0.
	buffer write: 4 from: '1234' at: 1.
	self assert: (buffer cache first: 4) = '1234'.
	self assert: buffer cacheSize = 8.
	self assert: buffer activeSize = 4.
	self assert: buffer inactiveSize = 4.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 4! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:40'!
testWriteObject
	
	self assert: buffer cacheSize = 0.
	self assert: buffer activeSize = 0.
	self assert: buffer inactiveSize = 0.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 0.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 0.
	buffer put: $1.
	self assert: buffer cache first = $1.
	self assert: buffer cacheSize = 2.
	self assert: buffer activeSize = 1.
	self assert: buffer inactiveSize = 1.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 1.
	self assert: buffer readSize = 1.
	self assert: buffer writeSize = 1.
	buffer put: $2; put: $3; put: $4.
	self assert: (buffer cache first: 4) = '1234'.
	self assert: buffer cacheSize = 6.
	self assert: buffer activeSize = 4.
	self assert: buffer inactiveSize = 2.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 2.
	buffer put: $5.
	self assert: (buffer cache first: 5) = '12345'.
	self assert: buffer cacheSize >= 5.
	self assert: buffer activeSize = 5.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 5.
	self assert: buffer readSize = 5.! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:40'!
testWriteWrap

	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 2 into: output at: 1.
	buffer write: 6 from: 'ABCDEF' at: 1.
	self assert: buffer cache = 'EF34ABCD'.
	self assert: buffer cacheSize = 8.
	self assert: buffer activeSize = 8.
	self assert: buffer inactiveSize = 0.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 8.
	self assert: buffer readSize = 8.
	self assert: buffer writeSize = 0! !

!XTElasticBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 20:40'!
testWriteWrapOverflow

	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 2 into: output at: 1.
	buffer write: 5 from: 'ABCDE' at: 1.
	buffer write: 3 from: 'XYZ' at: 1.
	self assert: (buffer cache first: 4) = 'EXYZ'.
	self assert: (buffer cache last: 4) = 'ABCD'.
	self assert: buffer cacheSize = 20.
	self assert: buffer activeSize = 11.
	self assert: buffer inactiveSize = 9.
	self assert: buffer readPosition = 1.
	self assert: buffer writePosition = 11.
	self assert: buffer readSize = 10.
	self assert: buffer writeSize = 10! !

TestCase subclass: #XTPositionReadStreamTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-CoreTests'!

!XTPositionReadStreamTest methodsFor: 'tests' stamp: 'MartinKobetic 1/11/2011 17:53'!
testIncompleteCounts

	| x oneToTen |
	oneToTen := [ (x := x + 1) > 10 ifTrue: [ Incomplete zero raise ]. x ].
	x := 0.
	self assert: ([ oneToTen reading positioning read: 5; -- 8 ] on: Incomplete do: [:ex | ex count]) = 5.
	x := 0.
	self assert: ([ oneToTen reading positioning read: 5; ++ 8 ] on: Incomplete do: [:ex | ex count]) = 5.
	x := 0.
	self assert: ([ oneToTen reading positioning -= 12 ] on: Incomplete do: [:ex | ex count]) = 10.
	x := 0.
	self assert: ([ oneToTen reading positioning += 12 ] on: Incomplete do: [:ex | ex count]) = 10.
	self assert: ([ (1 to: 10) reading positioning read: 5; -- 8 ] on: Incomplete do: [:ex | ex count]) = 5.
	self assert: ([ (1 to: 10) reading positioning read: 5; ++ 8 ] on: Incomplete do: [:ex | ex count]) = 5.
	self assert: ([ (1 to: 10) reading positioning -= 12 ] on: Incomplete do: [:ex | ex count]) = 10.
	self assert: ([ (1 to: 10) reading positioning += 12 ] on: Incomplete do: [:ex | ex count]) = 10.! !

TestCase subclass: #XTPositionWriteStreamTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-CoreTests'!

!XTPositionWriteStreamTest methodsFor: 'tests' stamp: 'MartinKobetic 1/11/2011 17:53'!
testIncompleteCounts

	self assert: ([ ([ :x | ] writing limiting: 10) positioning write: (1 to: 5); -- 8 ] on: Incomplete do: [:ex | ex count]) = 5.
	self assert: ([ ([ :x | ] writing limiting: 10) positioning write: (1 to: 5); ++ 8 ] on: Incomplete do: [:ex | ex count]) = 0.
	self assert: ([ ([ :x | ] writing limiting: 10) positioning write: (1 to: 5); -= 12 ] on: Incomplete do: [:ex | ex count]) = 5.
	self assert: ([ ([ :x | ] writing limiting: 10) positioning write: (1 to: 5); += 12 ] on: Incomplete do: [:ex | ex count]) = 5.
	self assert: ([ (Array new: 10) writing positioning write: (1 to: 5); -- 8 ] on: Incomplete do: [:ex | ex count]) = 5.
	self assert: ([ (Array new: 10) writing positioning write: (1 to: 5); ++ 8 ] on: Incomplete do: [:ex | ex count]) = 0.
	self assert: ([ (Array new: 10) writing positioning write: (1 to: 5); -= 12 ] on: Incomplete do: [:ex | ex count]) = 5.
	self assert: ([ (Array new: 10) writing positioning write: (1 to: 5); += 12 ] on: Incomplete do: [:ex | ex count]) = 5.! !

TestCase subclass: #XTReadingWritingTest
	instanceVariableNames: 'output input'
	classVariableNames: ''
	poolDictionaries: 'XTPools'
	category: 'Xtreams-CoreTests'!

XTReadingWritingTest subclass: #XTFiniteReadingWritingTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-CoreTests'!

!XTFiniteReadingWritingTests commentStamp: 'nice 10/9/2010 21:19' prior: 0!
These are tests that require a stream that can be effectively closed, i.e. not pointer or shared queue stream.

!

!XTFiniteReadingWritingTests methodsFor: 'tests - enumeration' stamp: 'nice 10/15/2010 11:53'!
testCollect

	| data result |
	data := ByteArray withAll: (0 to: 15).
	self output write: data; close.
	result := self input collect: [ :e | e * e ].
	self assert: result size = data size.
	data with: result do: [ :in :out | self assert: in * in = out ]! !

!XTFiniteReadingWritingTests methodsFor: 'tests - enumeration' stamp: 'nice 10/15/2010 11:51'!
testDetect

	| data result |
	data := ByteArray withAll: (1 to: 15).
	self output write: data; close.
	result := self input detect: [ :e | e \\ 4 = 0 ].
	self assert: result = 4.
	result := self input detect: [ :e | e \\ 4 = 0 ].
	self assert: result = 8.
	result := self input detect: [ :e | e \\ 4 = 0 ].
	self assert: result = 12.
	result := self input detect: [ :e | e \\ 4 = 0 ] ifNone: [ nil ].
	self assert: result = nil! !

!XTFiniteReadingWritingTests methodsFor: 'tests - enumeration' stamp: 'nice 10/15/2010 11:46'!
testDo

	| data result i |
	data := ByteArray withAll: (0 to: 15).
	self output write: data; close.
	result := ByteArray new: data size.
	i := 1.
	self input do: [ :e | result at: i put: e * e. i := i + 1 ].
	data with: result do: [ :in :out | self assert: in * in = out ]! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testExploreInsideExplore
	| in |
	self output write: #[ 1 2 3 4 ]; close.
	in := self input positioning.
	self assert: (in explore: [(in explore: [in rest = #[1 2 3 4]]) & (in rest = #[1 2 3 4])]).
	self assert: in rest = #[1 2 3 4].
	self should: [in get] raise: Incomplete! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testExploreRead
	| in |
	self output write: #[ 1 2 3 4 ]; close.
	in := self input positioning.
	self assert: (in explore: [in rest = #[1 2 3 4]]).
	self assert: in rest = #[1 2 3 4].
	self should: [in get] raise: Incomplete! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testExploreSeekBackward
	| in |
	self output write: #[ 1 2 3 4 ]; close.
	in := self input positioning.
	self assert: (in explore: [in read: 3; -- 1. in rest = #[3 4]]).
	self assert: in rest = #[1 2 3 4].
	self should: [in get] raise: Incomplete! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testExploreSeekBackwardPastBeginning
	| in |
	self output write: #[ 1 2 3 4 ]; close.
	in := self input positioning.
	self should: [ in explore: [in read: 2; -- 4 ] ] raise: Incomplete.
	self should: [ in explore: [in read: 2; -= 6 ] ] raise: Incomplete.
	self assert: in rest = #[1 2 3 4].
	self should: [in get] raise: Incomplete! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testExploreSeekForward
	| in |
	self output write: #[ 1 2 3 4 ]; close.
	in := self input positioning.
	self assert: (in explore: [in ++ 2. in rest = #[3 4]]).
	self assert: in rest = #[1 2 3 4].
	self should: [in get] raise: Incomplete! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testExploreSeekForwardPastEnd
	| in |
	self output write: #[ 1 2 3 4 ]; close.
	in := self input positioning.
	self should: [ in explore: [in ++ 8] ] raise: Incomplete.
	self should: [ in explore: [in += 8] ] raise: Incomplete.
	self assert: in rest = #[1 2 3 4].
	self should: [in get] raise: Incomplete! !

!XTFiniteReadingWritingTests methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:53'!
testGet
	self output write: #[ 1 2 3 4 ]; close.
	self assert: self input get = 1.
	self assert: self input get = 2.
	self assert: self input get = 3.
	self assert: self input get = 4.
	self should: [self input get] raise: Incomplete! !

!XTFiniteReadingWritingTests methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:53'!
testGetPastEnd
	self output put: 120.
	self output close.
	self assert: self input get = 120.
	self should: [self input get] raise: Incomplete! !

!XTFiniteReadingWritingTests methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:53'!
testRead

	self output write: #[ 1 2 3 4 ]; close.
	self assert: (self input read: 3) = #[1 2 3].
	self assert: ([self input read: 2. false] on: Incomplete do: [:exception |
		exception collection first = 4.
		exception collection size = 2.
		exception count = 1.
		true])! !

!XTFiniteReadingWritingTests methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:53'!
testReadIntoAt
	| result |
	self output write: #[ 1 2 3 4 ]; close.
	result := ByteArray new: 8 withAll: 255.
	self input read: 3 into: result at: 3.
	self assert: result = #[255 255 1 2 3 255 255 255].
	self input read: 1 into: result at: 6.
	self assert: result = #[255 255 1 2 3 4 255 255].
	self should: [self input get] raise: Incomplete.
	self should: [self input read: 3 into: result at: 5] raise: Incomplete.
	self assert: result = #[255 255 1 2 3 4 255 255].! !

!XTFiniteReadingWritingTests methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:53'!
testReadIntoAtPastEnd
	| result |

	self output write: #[ 1 2 3 4 ]; close.
	self input read: 1.
	result := ByteArray new: 4 withAll: 255.
	self assert: ([self input read: 4 into: result at: 1. false] on: Incomplete do: [ :eos | eos count = 3 ]).
	self assert: result = #[2 3 4 255]! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testReadPositioningSeek

	| record in |
	record := #[ 1 2 3 4 5 6 7 8 9 0 ].
	self output write: record; close.
	in := self input positioning.
	self assert: (in ++ 7) = 7.
	self assert: in position = 7.
	self assert: (in -- 3) = 3.
	self assert: in position = 4.
	self assert: ([ in ++ record size ] on: Incomplete do: [:ex | ex count]) = (record size - 4).! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testReadPositioningSeekFrom

	| record in |
	record := #[ 1 2 3 4 5 6 7 8 9 0 ].
	self output write: record; close.
	in := self input positioning. 
	self assert: (in += 3) = 3.
	self assert: in position = 3.
	self assert: (in -= 4) = 4.
	self assert: in position = 6.
	self assert: ([ in -= (record size + 6) ] on: Incomplete do: [:ex | ex count]) = record size.
	self assert: in position = 0.
	self assert: ([ in += (record size + 6) ] on: Incomplete do: [:ex | ex count]) = record size.
	self assert: in position = record size.! !

!XTFiniteReadingWritingTests methodsFor: 'tests - core' stamp: 'nice 10/15/2010 11:40'!
testRest

	self output write: #[ 1 2 3 4 ]; close.
	self assert: self input rest = #[1 2 3 4].
	self assert: self input rest = #[]! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'nice 10/15/2010 11:53'!
testSeekBackward

	self output write: #[ 1 2 3 4 ]; close.
	self input read: 2.
	[self input -- 2] on: Error do: [:error |
		self deny: self input isPositionable].
	self input isPositionable
		ifTrue:	[self assert: self input rest = #[1 2 3 4]]
		ifFalse:	[self assert: self input rest = #[3 4]].! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testSeekBackwardPastBeginning

	self output write: #[ 1 2 3 4 ]; close.
	[[self input -- 1]
		on: Incomplete do: [:incomplete | ^self assert: incomplete count = 0]]
		on: Error do: [:error | ^self deny: self input isPositionable].

	"If neither exception was raised, that is a problem."
	self deny: true! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 12/30/2010 23:04'!
testSeekForward

	self output write: #[ 1 2 3 4 ]; close.
	self assert: (self input ++ 2) = 2.
	self assert: self input rest = #[3 4].! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testSeekForwardPastEnd

	self output write: #[ 1 2 3 4 ]; close.
	self input ++ 2.
	self assert: (
		[	self input ++ 4. false
		] on: Incomplete do: [ :eos |
			eos count = 2 ]).
	self should: [ self input get ] raise: Incomplete.
	self assert: (
		[	self input ++ 4. false
		] on: Incomplete do: [ :eos |
			eos count = 0 ]).! !

!XTFiniteReadingWritingTests methodsFor: 'tests - enumeration' stamp: 'nice 10/15/2010 11:54'!
testSelect

	| data result |
	data := ByteArray withAll: (0 to: 15).
	self output write: data; close.
	result := self input select: [ :e | e odd ].
	self assert: result = (data select: [ :e | e odd ]).! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'dkh 3/12/2011 15:33'!
testWritePositioningInsert

	| message result |
	message :=  ByteArray withAll: (1 to: 20).
	(XTPositionWriteStream on: self output)
		write: message; write: message;
		+= message size;
		insert: message;
		-= 0;
		close.
	result := self input rest.
	self assert: result = (message, message, message)! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testWritePositioningSeek

	| record out |
	record := #[ 1 2 3 4 5 6 7 8 9 0 ].
	out := self output positioning.
	out	write: record.
	self assert: (out -- 7) = 7.
	self assert: out position = 3.
	self assert: (out ++ 3) = 3.
	self assert: out position = 6.
	self assert: ([ out ++ record size ] on: Incomplete do: [:ex | ex count]) = (record size - 6).
	out close.
	self assert: (self input read: record size) = record! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 17:53'!
testWritePositioningSeekFrom

	| record out |
	record := #[ 1 2 3 4 5 6 7 8 9 0 ].
	out := self output positioning.
	out	write: record.
	self assert: (out += 3) = 3.
	self assert: out position = 3.
	self assert: (out -= 4) = 4.
	self assert: out position = 6.
	self assert: ([ out -= (record size + 6) ] on: Incomplete do: [:ex | ex count]) = record size.
	self assert: out position = 0.
	self assert: ([ out += (record size + 6) ] on: Incomplete do: [:ex | ex count]) = record size.
	self assert: out position = record size.
	out close.
	self assert: (self input read: record size) = record! !

!XTFiniteReadingWritingTests methodsFor: 'tests - seeking' stamp: 'MartinKobetic 1/11/2011 18:06'!
testWritePositioningWithRingBuffer

	| message result |
	message := ByteArray withAll: (1 to: 20).
	(XTPositionWriteStream on: self output)
		buffer: (XTRingBuffer on: (ByteArray new: 5));
		write: message;
		close.
	result := self input rest.
	self assert: result = message! !

!XTFiniteReadingWritingTests methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:53'!
testWriteStream
	| data |
	data := #[ 1 2 3 4 ] reading.
	self assert: (self output write: data) = 4.
	self shouldnt: [ self output write: data ] raise: Incomplete.
	self output close.
	self assert: (self input read: 4) = #[ 1 2 3 4 ].
	self should: [self input get] raise: Incomplete! !

!XTFiniteReadingWritingTests methodsFor: 'tests - core' stamp: 'nice 10/20/2010 22:35'!
testWriteTruncating

	self output positioning
		write: #[1 2 3 4 5 6];
		-- 3;
		write: #[1 2];
		close.
	self assert: self input rest = #[1 2 3 1 2].! !

XTReadingWritingTest subclass: #XTInfiniteReadingWritingTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-CoreTests'!

!XTInfiniteReadingWritingTests commentStamp: 'nice 10/9/2010 21:19' prior: 0!
These are tests specifically for those streams that cannot be effectively closed, i.e. pointer and shared queue streams.

!

!XTInfiniteReadingWritingTests class methodsFor: 'testing' stamp: 'DaleHenrichs 03/11/2011 20:54'!
isAbstract

	^self name == #XTInfiniteReadingWritingTests! !

!XTInfiniteReadingWritingTests methodsFor: 'tests - core' stamp: 'nice 10/15/2010 11:56'!
testGet
	self output write: #[ 1 2 3 4 ].
	self assert: self input get = 1.
	self assert: self input get = 2.
	self assert: self input get = 3.
	self assert: self input get = 4! !

!XTInfiniteReadingWritingTests methodsFor: 'tests - core' stamp: 'nice 10/15/2010 11:56'!
testRead
	self output write: #[ 1 2 3 4 ].
	self assert: (self input read: 3) = #[1 2 3].
	self assert: self input get = 4! !

!XTReadingWritingTest class methodsFor: 'testing' stamp: 'nice 10/9/2010 22:41'!
isAbstract
	^self subclasses notEmpty
	! !

!XTReadingWritingTest methodsFor: 'blocking utilities' stamp: 'nice 10/20/2010 23:01'!
concurrentTimeout: timeoutDuration server: serverBlock client: clientBlock
	"For tests that must be able to write and read at the same time, where they may block on each.
	 Sockets, Pipes have an operating system buffer which dictates its bandwidth."

	|	timeout
		serverSuccess serverProcess serverLock
		clientSuccess clientProcess clientLock
		end |

	timeout := false.
	serverLock := Semaphore new.
	clientLock := Semaphore new.
	serverSuccess := clientSuccess := false.
	serverProcess := [serverSuccess := serverBlock value. serverLock signal] newProcess.
	clientProcess := [clientSuccess := clientBlock value. clientLock signal] newProcess.

	end := DateAndTime now + timeoutDuration.
	serverProcess priority: Processor activeProcess priority - 1; resume.
	clientProcess priority: Processor activeProcess priority - 1; resume.

	((serverLock waitTimeoutMSecs: (end - DateAndTime now) asMilliSeconds) or: [
		clientLock waitTimeoutMSecs: (end - DateAndTime now) asMilliSeconds])
			ifTrue: [
				serverProcess terminate.
				output ifNotNil: [output close].
				clientProcess terminate.
				input ifNotNil: [input close].
				timeout := true ].

	self assert: serverSuccess.
	self assert: clientSuccess.
	self deny: timeout! !

!XTReadingWritingTest methodsFor: 'accessing' stamp: 'MartinKobetic 1/11/2011 17:22'!
input

	^input! !

!XTReadingWritingTest methodsFor: 'accessing' stamp: 'MartinKobetic 1/11/2011 17:22'!
output

	^output! !

!XTReadingWritingTest methodsFor: 'blocking utilities' stamp: 'nice 10/13/2010 21:10'!
sequentialTimeout: timeoutDuration server: serverBlock client: clientBlock

	self assert: serverBlock value.
	self assert: clientBlock value.! !

!XTReadingWritingTest methodsFor: 'tests - core' stamp: 'DaleHenrichs 03/11/2011 20:26'!
testInsert
	self output write: #[ 1 2 3 4 7 8 9 0 ].
	[self output -- 4] on: Error do: [:ex | self deny: self output isPositionable].
	self assert: (self output insert: #[ 5 6 ]) = 2.
	self input isPositionable
		ifTrue:	[self assert: (self input read: 10) = #[ 1 2 3 4 5 6 7 8 9 0 ]]
		ifFalse:	[self assert: (self input read: 10) = #[ 1 2 3 4 7 8 9 0 5 6 ]]! !

!XTReadingWritingTest methodsFor: 'tests - core' stamp: 'nice 10/15/2010 11:38'!
testPut
	
	self output put: 1.
	self assert: self input get = 1! !

!XTReadingWritingTest methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:23'!
testReadIntoCollection
	
	| data out |
	data := #[1 2 3 4 5 6 7].
	self output write: data; close.
	out := ByteArray new: data size.
	self assert: (self input read: 4 into: out) = 4.
	self assert: (self input read: 3 into: out at: 5)  = 3.
	self assert: out = data! !

!XTReadingWritingTest methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:23'!
testReadPositioningSeek

	| record in |
	record := #[ 1 2 3 4 5 6 7 8 9 0 ].
	self output write: record; close.
	in := self input positioning.
	self assert: (in ++ 7) = 7.
	self assert: in position = 7.
	self assert: (in -- 3) = 3.
	self assert: in position = 4.! !

!XTReadingWritingTest methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:23'!
testReadWriteLargeAmount
	| data |
	1 to: 10 do: [:each | self output put: 1. self assert: self input get = 1].
	#( 64 1024 2048 4096 8192 ) do: [:dataSize |
		data := ByteArray new: dataSize.
		1 to: data size do: [:i | data at: i put: (i - 1) \\ 256].
		self	timeout:	1000 milliseconds
			server:	[1 to: 10 do: [:each | self output write: data]. true]
			client: 	[(1 to: 10) inject: true into: [:pass :each | pass and: [(self input read: data size) = data]]]]! !

!XTReadingWritingTest methodsFor: 'tests - core' stamp: 'MartinKobetic 12/30/2010 23:07'!
testWriteCollection
	
	| data |
	data := #[1 2 3 4 5 6 7].
	self assert: (self output write: data) = data size.
	self assert: (self input read: data size) = data! !

!XTReadingWritingTest methodsFor: 'tests - core' stamp: 'nice 10/20/2010 22:37'!
testWriteExplore

	| record mark out |
	record := #[ 1 2 3 4 5 6 7 8 9 0 ].
	out := self output positioning.
	mark := out position.
	out
		write: 0;
		write: record;
		explore: [out += mark; write: record size];
		close.
	self assert: (self input read: record size + 1) = ((ByteArray with: record size), record)! !

!XTReadingWritingTest methodsFor: 'tests - core' stamp: 'MartinKobetic 12/30/2010 23:09'!
testWriteFromCollectionAt

	| data |
	data := #[1 2 3 4 5 6 7].
	self assert: (self output write: 4 from: data at: 1) = 4.
	self assert: (self input read: 4) = (data first: 4).
	self assert: (self output write: 3 from: data at: 5) = 3.
	self assert: (self input read: 3) = (data last: 3)! !

!XTReadingWritingTest methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:53'!
testWriteFromStream
	| data |
	data := #[ 1 2 3 4 ] reading.
	self assert: (self output write: 3 from: data) = 3.
	self assert: (self input read: 3) = #[ 1 2 3 ].
	self assert: (self output write: 1 from: data) = 1.
	self assert: self input get = 4.
	self assert: (
		[	self output write: 2 from: data. false
		] on: Incomplete do: [ :eos |
			eos count = 0 ])! !

!XTReadingWritingTest methodsFor: 'tests - core' stamp: 'MartinKobetic 1/11/2011 17:24'!
testWritePositioningSeek

	| record out |
	record := #[ 1 2 3 4 5 6 7 8 9 0 ].
	out := self output positioning.
	out	write: record.
	self assert: (out -- 7) = 7.
	self assert: out position = 3.
	self assert: (out ++ 3) = 3.
	self assert: out position = 6.
	self assert: (out ++ 4) = 4.
	out close.
	self assert: (self input read: record size) = record! !

!XTReadingWritingTest methodsFor: 'blocking utilities' stamp: 'nice 10/13/2010 21:11'!
timeout: timeoutDuration server: serverBlock client: clientBlock
	"Tests that must be able to write and read at the same time, where they may block on each will have to redefine this message.
	 For example, Sockets, Pipes have an operating system buffer which dictates its bandwidth.
	 This default version simply execute server then client sequentially."

	self sequentialTimeout: timeoutDuration server: serverBlock client: clientBlock! !

TestCase subclass: #XTRingBufferTest
	instanceVariableNames: 'output buffer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xtreams-CoreTests'!

!XTRingBufferTest methodsFor: 'initialize-release' stamp: 'nice 10/9/2010 21:14'!
setUp
	
	buffer := XTRingBuffer on: 'xxxx' copy! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:15'!
testClear

	| cacheSize |
	buffer write: 4 from: '1234' at: 1.
	cacheSize := buffer cacheSize.
	buffer clear.
	self assert: buffer cacheSize = cacheSize.
	self assert: buffer readPosition = 0.
	self assert: buffer readSize = 0.
	self assert: buffer writePosition = 0.
	self assert: buffer writeSize = cacheSize! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:15'!
testInsertInTheMiddle

	| chunk |
	chunk := 'hello'.
	buffer := XTRingBuffer on: (String new: chunk size * 5).
	buffer write: chunk; write: chunk.
	buffer writePosition: chunk size.
	buffer insert: chunk.
	self assert: buffer writePosition = (chunk size * 2).
	self assert: buffer activeSize = (chunk size * 3)! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:16'!
testRead

	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 1 into: output at: 1.
	self assert: output = '1www'.
	self assert: buffer readPosition = 1.
	self assert: buffer readSize = 3.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 1.
	buffer read: 3 into: output at: 2.
	self assert: output = '1234'.
	self assert: buffer readPosition = 4.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 4! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'MartinKobetic 1/11/2011 17:53'!
testReadOverflow

	output := 'wwwwww' copy.
	buffer write: 4 from: '1234' at: 1.
	self should: [buffer read: 6 into: output at: 1] raise: Incomplete.
	self assert: output = '1234ww'.
	self assert: buffer readPosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 4! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:17'!
testReadWrap

	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 3 into: output at: 1.
	buffer write: 3 from: 'ABC' at: 1.
	output := 'wwww' copy.
	buffer read: 4 into: output at: 1.
	self assert: output = '4ABC'.
	self assert: buffer readPosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 4! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:17'!
testReadWriteFirstHalf

	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 2 into: output at: 1.
	self assert: output = '12ww'.
	self assert: buffer cache = '1234'.
	self assert: buffer readPosition = 2.
	self assert: buffer readSize = 2.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 2.
	buffer write: 2 from: 'AB' at: 1.
	self assert: buffer cache = 'AB34'.
	self assert: buffer readPosition = 0.
	self assert: buffer readSize = 4.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 0.
	output := 'wwww' copy.
	buffer read: 2 into: output at: 1.
	self assert: output = '34ww'.
	self assert: buffer readPosition = 2.
	self assert: buffer readSize = 2.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 2! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:17'!
testReadWriteSecondHalf
	" <--- SomeData ... ReadAt ... WriteAt/DataEnd DataStart ... SomeData ---> "

	output := 'wwww' copy.
	buffer write: 3 from: '123' at: 1.
	buffer read: 3 into: output at: 1.
	buffer write: 3 from: 'ABC' at: 1.
	buffer read: 2 into: output at: 1.
	output := 'wwww' copy.
	buffer read: 1 into: output at: 1.
	self assert: output = 'Cwww'.
	self assert: buffer readPosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 4! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:17'!
testReadWriteWrap

	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 3 into: output at: 1.
	self assert: output = '123w'.
	self assert: buffer cache = '1234'.
	self assert: buffer readPosition = 3.
	self assert: buffer readSize = 1.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 3.
	buffer write: 1 from: 'A' at: 1.
	self assert: buffer cache = 'A234'.
	self assert: buffer readPosition = 2.
	self assert: buffer readSize = 2.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 2.
	buffer write: 2 from: 'BC' at: 1.
	self assert: buffer cache = 'ABC4'.
	self assert: buffer readPosition = 0.
	self assert: buffer readSize = 4.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 0.
	output := 'wwww' copy.
	buffer read: 4 into: output at: 1.
	self assert: output = '4ABC'.
	self assert: buffer readPosition = 4.
	self assert: buffer readSize = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer writeSize = 4! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:18'!
testTrim

	output := 'wwww' copy.
	buffer write: 3 from: '1234' at: 1.
	buffer read: 1 into: output at: 1.
	buffer writeSkip: -1.
	buffer trim.
	self assert: buffer cacheSize = 2.
	self assert: buffer cache = '23'.
	self assert: buffer readPosition = 0.
	self assert: buffer readSize = 2.
	self assert: buffer writePosition = 2.
	self assert: buffer writeSize = 0! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:18'!
testTrimInsideOut

	output := 'wwww' copy.
	buffer write: 4 from: '1234' at: 1.
	buffer read: 3 into: output at: 1.
	buffer write: 2 from: 'AB' at: 1.
	buffer writeSkip: -1.
	buffer trim.
	self assert: buffer cacheSize = 2.
	self assert: buffer cache = '4B'.
	self assert: buffer readPosition = 0.
	self assert: buffer readSize = 2.
	self assert: buffer writePosition = 2.
	self assert: buffer writeSize = 0! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:18'!
testWrite

	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 0.
	self assert: buffer inactiveSize = 4.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 0.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 4.
	buffer write: 1 from: '1234' at: 1.
	self assert: buffer cache = '1xxx'.
	self assert: buffer activeSize = 1.
	self assert: buffer inactiveSize = 3.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 1.
	self assert: buffer readSize = 1.
	self assert: buffer writeSize = 3.
	buffer write: 3 from: '1234' at: 2.
	self assert: buffer cache = '1234'.
	self assert: buffer activeSize = 4.
	self assert: buffer inactiveSize = 0.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 0! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:18'!
testWriteObject
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 0.
	self assert: buffer inactiveSize = 4.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 0.
	self assert: buffer readSize = 0.
	self assert: buffer writeSize = 4.
	
	buffer put: $1.
	self assert: buffer cache first = $1.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 1.
	self assert: buffer inactiveSize = 3.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 1.
	self assert: buffer readSize = 1.
	self assert: buffer writeSize = 3.
	buffer put: $2; put: $3; put: $4.
	self assert: buffer cache = '1234'.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 4.
	self assert: buffer inactiveSize = 0.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 0.
	buffer put: $5.
	self assert: buffer cache = '5234'.
	self assert: buffer cacheSize = 4.
	self assert: buffer activeSize = 4.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:18'!
testWriteOverflow0

	buffer write: 1 from: '1234' at: 1.
	buffer write: 4 from: 'ABCD' at: 1.
	self assert: buffer cache = 'ABCD'.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 0! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:18'!
testWriteOverflow1

	buffer write: 1 from: '1234' at: 1.
	buffer write: 5 from: 'ABCDE' at: 1.
	self assert: buffer cache = 'BCDE'.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 0! !

!XTRingBufferTest methodsFor: 'tests' stamp: 'nice 10/9/2010 21:18'!
testWriteWrap

	buffer write: 3 from: '1234' at: 1.
	buffer write: 2 from: 'AB' at: 1.
	self assert: buffer cache = 'B23A'.
	self assert: buffer readPosition = 0.
	self assert: buffer writePosition = 4.
	self assert: buffer readSize = 4.
	self assert: buffer writeSize = 0! !
